@@ -7,7 +7,7 @@ reuse.
 
 """
 from numbers import Real
-from typing import Any, Iterable, Tuple
+from typing import Iterable
 
 import numpy as np
 
@@ -20,7 +20,6 @@ __all__ = ["processed_property"]
 
 class property(property):
     """Subclass in-built property type so attributes can be set."""
-    pass
 
 
 def processed_property(name, **kwargs):
@@ -30,7 +29,7 @@ def processed_property(name, **kwargs):
     ----------
     name : str
         Attribute name that will be used for the property.
-    read_only : bool, False
+    read_only : bool
         If a processed property is specified as read-only then after its value
         has been set once (i.e. after it has been instantiated), it is not able
         to be set again.
@@ -38,13 +37,13 @@ def processed_property(name, **kwargs):
         Tells the processed property the type of the value that the setter is
         expecting. If the value passed to the setter is not of this type then a
         TypeError will be raised.
-    cast : bool, False
+    cast : bool
         Defines whether the value passed to the processed property's setter
         should be attempted to be cast to the expected type.
-    optional : bool, False
+    optional : bool
         In additional to other specifications for the processed property, a
         value of `None` is also accepted.
-    default : obj, None
+    default : Optional[object]
         If a processed property is specified as `optional`, then if a value of
         `None` is supplied to the setter this is instead replaced with this
         specified default value.
@@ -60,13 +59,17 @@ def processed_property(name, **kwargs):
     def parse_kwarg(kwarg_name, description, valids, default):
         kwarg = kwargs.get(kwarg_name, default)
         if isinstance(valids, type) and not isinstance(kwarg, valids):
-            msg = (f"{repr(kwarg)} is not a valid {description}. Please "
-                   f"use a value of type {repr(valids)}.")
+            msg = (
+                f"{repr(kwarg)} is not a valid {description}. Please "
+                f"use a value of type {repr(valids)}."
+            )
             raise TypeError(msg)
         elif not isinstance(valids, type) and kwarg not in valids:
             formatted_valids = format_for_output(valids, with_or=True)
-            msg = (f"{repr(kwarg)} is not a valid {description}. Please "
-                   f"choose one of: {formatted_valids}.")
+            msg = (
+                f"{repr(kwarg)} is not a valid {description}. Please "
+                f"choose one of: {formatted_valids}."
+            )
             raise ValueError(msg)
         return kwarg
 
@@ -91,20 +94,24 @@ def processed_property(name, **kwargs):
         if isinstance(options, Options):
             return options.options, options.unsupported
         if (options is None and unsupported_options) or (
-                set(unsupported_options).difference(set(options))):
-            msg = (f"{name_str} does not have any supported options. Check "
-                   f"unsupported options are valid options: "
-                   f"{format_for_output(unsupported_options)}.")
+            set(unsupported_options).difference(set(options))
+        ):
+            msg = (
+                f"{name_str} does not have any supported options. Check "
+                f"unsupported options are valid options: "
+                f"{format_for_output(unsupported_options)}."
+            )
             raise ValueError(msg)
         if not set(options).symmetric_difference(set(unsupported_options)):
-            msg = (f"{name_str} does not have any supported options from: "
-                   f"{format_for_output(options)}.")
+            msg = (
+                f"{name_str} does not have any supported options from: "
+                f"{format_for_output(options)}."
+            )
             raise ValueError(msg)
         return tuple(options), tuple(unsupported_options)
 
     def generate_setter_dispatcher():
         setter_dispatcher = {}
-        no_args_kwargs = ((), {})
         if read_only:
             args = (storage_name, name_str)
             kwargs = {"instance": True}
@@ -121,7 +128,7 @@ def processed_property(name, **kwargs):
             )
             setter_dispatcher.update({check_expected_type: (args, {})})
         if str_format:
-            args = (str_format, )
+            args = (str_format,)
             kwargs = {"process": True}
             setter_dispatcher.update({format_str_case: (args, kwargs)})
         if options is not None:
@@ -157,7 +164,7 @@ def processed_property(name, **kwargs):
             args = (len_sequence, name_str)
             setter_dispatcher.update({check_len: (args, {})})
         if optimisable:
-            args = (name_str, )
+            args = (name_str,)
             setter_dispatcher.update({process_optimisable: (args, {})})
             setattr(property, "is_optimisable", optimisable)
         if post_method is not None:
@@ -185,15 +192,17 @@ def processed_property(name, **kwargs):
     at_least = kwargs.get("at_least")
     at_most = kwargs.get("at_most")
     equal_to = kwargs.get("equal_to")
-    str_format = parse_kwarg("str_format", "string case format",
-                             SUPPORTED_STR_FORMAT_OPTIONS, None)
+    str_format = parse_kwarg(
+        "str_format", "string case format", SUPPORTED_STR_FORMAT_OPTIONS, None
+    )
     read_only = kwargs.get("read_only")
 
     # Additional error checking of kwargs
     name_str = generate_name_description_error_message(name, description)
     if options or unsupported_options:
         options, unsupported_options = error_check_option_kwarg(
-            options, unsupported_options)
+            options, unsupported_options
+        )
 
     setter_dispatcher = generate_setter_dispatcher()
 
@@ -227,45 +236,50 @@ def processed_property(name, **kwargs):
                 kwargs["instance"] = self
             value = method(value, *args, **kwargs)
         setattr(self, storage_name, value)
-        setattr(self, f"{storage_name}_dir", {
-            "name": name,
-            "description": description
-        })
+        setattr(self, f"{storage_name}_dir", {"name": name, "description": description})
 
     return prop
 
 
 def check_read_only(value, storage_name, name_str, *, instance):
     if hasattr(instance, storage_name):
-        msg = (f"{name_str} is a read-only property and cannot be reset "
-               f"after it has been initialised.")
+        msg = (
+            f"{name_str} is a read-only property and cannot be reset "
+            f"after it has been initialised."
+        )
         raise AttributeError(msg)
     return value
 
 
-def check_expected_type(value, iterable_allowed, expected_type, name_str,
-                        optional, cast_to_type, default):
+def check_expected_type(
+    value, iterable_allowed, expected_type, name_str, optional, cast_to_type, default
+):
     if iterable_allowed:
         if isinstance(value, Iterable):
-            value = tuple([
-                check_type(val, expected_type, name_str, optional,
-                           cast_to_type, default) for val in value
-            ])
+            value = tuple(
+                [
+                    check_type(
+                        val, expected_type, name_str, optional, cast_to_type, default
+                    )
+                    for val in value
+                ]
+            )
         elif (value is None) and optional:
             if default is not None:
                 return default
             return None
         else:
-            value = check_type(value, expected_type, name_str, optional,
-                               cast_to_type, default)
+            value = check_type(
+                value, expected_type, name_str, optional, cast_to_type, default
+            )
     else:
-        value = check_type(value, expected_type, name_str, optional,
-                           cast_to_type, default)
+        value = check_type(
+            value, expected_type, name_str, optional, cast_to_type, default
+        )
     return value
 
 
-def check_type(value, expected_type, name_str, optional, cast_to_type,
-               default):
+def check_type(value, expected_type, name_str, optional, cast_to_type, default):
     """Ensure the type of the property value to be set is as specified.
 
     Parameters
@@ -296,8 +310,10 @@ def check_type(value, expected_type, name_str, optional, cast_to_type,
         return None
     elif cast_to_type:
         return cast_type(value, expected_type, name_str)
-    msg = (f"{name_str} must be a {repr(expected_type)}, instead got "
-           f"a {repr(type(value))}.")
+    msg = (
+        f"{name_str} must be a {repr(expected_type)}, instead got "
+        f"a {repr(type(value))}."
+    )
     raise TypeError(msg)
 
 
@@ -328,14 +344,15 @@ def cast_type(value, expected_type, name_str):
     try:
         exec(cast_str)
     except (ValueError, TypeError):
-        msg = (f"{name_str} must be a {repr(expected_type)}, instead got "
-               f"a {repr(type(value))} which cannot be cast.")
+        msg = (
+            f"{name_str} must be a {repr(expected_type)}, instead got "
+            f"a {repr(type(value))} which cannot be cast."
+        )
         raise ValueError(msg)
     return locals()["processed_value"]
 
 
-def check_options(value, options, unsupported_options, name_str, name,
-                  description):
+def check_options(value, options, unsupported_options, name_str, name, description):
     """Ensure user-supplied value is a valid option.
 
     Options for property can fall in to two camps: valid options and
@@ -355,22 +372,25 @@ def check_options(value, options, unsupported_options, name_str, name,
         If value trying to be set is not a valid option or is an
         unsupported option.
     """
-    valid_options = [
-        option for option in options if option not in unsupported_options
-    ]
+    valid_options = [option for option in options if option not in unsupported_options]
     formatted_valid_options = format_for_output(valid_options, with_or=True)
     if value in unsupported_options:
         formatted_unsupported_option = format_for_output(value, with_verb=True)
         formatted_description = generate_name_description_error_message(
-            name, description, with_preposition=True)
-        msg = (f"{formatted_unsupported_option} not currently supported as "
-               f"{formatted_description}. Choose one of: "
-               f"{formatted_valid_options}.")
+            name, description, with_preposition=True
+        )
+        msg = (
+            f"{formatted_unsupported_option} not currently supported as "
+            f"{formatted_description}. Choose one of: "
+            f"{formatted_valid_options}."
+        )
         raise ValueError(msg)
     elif value not in options:
         formatted_value = format_for_output(value, with_verb=True)
-        msg = (f"{formatted_value} not a valid option of {name_str}. "
-               f"Choose one of: {formatted_valid_options}.")
+        msg = (
+            f"{formatted_value} not a valid option of {name_str}. "
+            f"Choose one of: {formatted_valid_options}."
+        )
         raise ValueError(msg)
     return value
 
@@ -395,18 +415,22 @@ def check_min(value, name, description, exclusive, min_value):
     Use function from py:mod:`utils` to format repr values with backticks.
 
     """
-    name_str = generate_name_description_error_message(name,
-                                                       description,
-                                                       is_sentence_start=True)
+    name_str = generate_name_description_error_message(
+        name, description, is_sentence_start=True
+    )
     if exclusive:
         if value <= min_value:
-            msg = (f"{name_str} must be greater than `{repr(min_value)}`. "
-                   f"`{repr(value)}` is invalid.")
+            msg = (
+                f"{name_str} must be greater than `{repr(min_value)}`. "
+                f"`{repr(value)}` is invalid."
+            )
             raise ValueError(msg)
     else:
         if value < min_value:
-            msg = (f"{name_str} must be greater than or equal to "
-                   f"`{repr(min_value)}`. `{repr(value)}` is invalid.")
+            msg = (
+                f"{name_str} must be greater than or equal to "
+                f"`{repr(min_value)}`. `{repr(value)}` is invalid."
+            )
             raise ValueError(msg)
     return value
 
@@ -431,18 +455,22 @@ def check_max(value, name, description, exclusive, max_value):
     Use function from py:mod:`utils` to format repr values with backticks.
 
     """
-    name_str = generate_name_description_error_message(name,
-                                                       description,
-                                                       is_sentence_start=True)
+    name_str = generate_name_description_error_message(
+        name, description, is_sentence_start=True
+    )
     if exclusive:
         if value >= max_value:
-            msg = (f"{name_str} must be less than `{repr(max_value)}`. "
-                   f"`{repr(value)}` is invalid.")
+            msg = (
+                f"{name_str} must be less than `{repr(max_value)}`. "
+                f"`{repr(value)}` is invalid."
+            )
             raise ValueError(msg)
     else:
         if value > max_value:
-            msg = (f"{name_str} must be less than or equal to "
-                   f"`{repr(max_value)}`. `{repr(value)}` is invalid.")
+            msg = (
+                f"{name_str} must be less than or equal to "
+                f"`{repr(max_value)}`. `{repr(value)}` is invalid."
+            )
             raise ValueError(msg)
     return value
 
@@ -451,8 +479,9 @@ def check_less_than(value, less_than, name, description, *, instance):
     def less_than_lambda(val_1, val_2):
         return val_1 < val_2
 
-    check_comparison(value, instance, less_than, "less than", less_than_lambda,
-                     name, description)
+    check_comparison(
+        value, instance, less_than, "less than", less_than_lambda, name, description
+    )
     return value
 
 
@@ -476,8 +505,9 @@ def check_at_least(value, at_least, name, description, *, instance):
     def at_least_lambda(val_1, val_2):
         return val_1 >= val_2
 
-    check_comparison(value, instance, at_least, "at least", at_least_lambda,
-                     name, description)
+    check_comparison(
+        value, instance, at_least, "at least", at_least_lambda, name, description
+    )
     return value
 
 
@@ -485,8 +515,9 @@ def check_at_most(value, at_most, name, description, *, instance):
     def at_most_lambda(val_1, val_2):
         return val_1 <= val_2
 
-    check_comparison(value, instance, at_most, "at most", at_most_lambda, name,
-                     description)
+    check_comparison(
+        value, instance, at_most, "at most", at_most_lambda, name, description
+    )
     return value
 
 
@@ -494,13 +525,15 @@ def check_equal_to(value, equal_to, name, description, *, instance):
     def equal_to_lambda(val_1, val_2):
         return val_1 == val_2
 
-    check_comparison(value, instance, equal_to, "equal to", equal_to_lambda,
-                     name, description)
+    check_comparison(
+        value, instance, equal_to, "equal to", equal_to_lambda, name, description
+    )
     return value
 
 
-def check_comparison(value, instance, other, comparison_description,
-                     comparison_func, name, description):
+def check_comparison(
+    value, instance, other, comparison_description, comparison_func, name, description
+):
     try:
         other_value = getattr(instance, ("_" + other))
     except AttributeError:
@@ -511,14 +544,18 @@ def check_comparison(value, instance, other, comparison_description,
             other_name = other_dir["name"]
             other_description = other_dir["description"]
             name_str = generate_name_description_error_message(
-                name, description, is_sentence_start=True)
+                name, description, is_sentence_start=True
+            )
             other_name_str = generate_name_description_error_message(
-                other_name, other_description)
+                other_name, other_description
+            )
             value_formatted = format_for_output(value)
             other_value_formatted = format_for_output(other_value)
-            msg = (f"{name_str} with value {value_formatted} must be "
-                   f"{comparison_description} {other_name_str} with "
-                   f"value {other_value_formatted}.")
+            msg = (
+                f"{name_str} with value {value_formatted} must be "
+                f"{comparison_description} {other_name_str} with "
+                f"value {other_value_formatted}."
+            )
             raise ValueError(msg)
 
 
@@ -591,17 +628,21 @@ def process_optimisable(value, name_str):
     if isinstance(value, Iterable):
         check_len(value, 2, name_str)
         bounds = []
-        msg = (f"Both {name_str} bounds must be of type {Real}, instead "
-               f"got {value[0]} at index 0 (type {type(value[0])}) and "
-               f"{value[1]} at index 1 (type {type(value[1])}).")
+        msg = (
+            f"Both {name_str} bounds must be of type {Real}, instead "
+            f"got {value[0]} at index 0 (type {type(value[0])}) and "
+            f"{value[1]} at index 1 (type {type(value[1])})."
+        )
         for bound in value:
             if not isinstance(bound, Real):
                 raise TypeError(msg)
             bounds.append(bound)
         bounds = check_bounds(bounds)
         return bounds
-    msg = (f"{name_str} must be a {Real} or {Iterable} of length 2, "
-           f"instead got {repr(type(value))}.")
+    msg = (
+        f"{name_str} must be a {Real} or {Iterable} of length 2, "
+        f"instead got {repr(type(value))}."
+    )
     raise TypeError(msg)
 
 
@@ -610,7 +651,7 @@ def check_bounds(bounds):
 
     Parameters
     ----------
-    bounds : :obj:`Iterable`
+    bounds : Iterable
         `Iterable` of bounds to be validated.
 
     Returns
@@ -635,14 +676,18 @@ def check_bounds(bounds):
         # Test if both bounds can be represented as signed 64-bit number.
         np.asarray(bounds, dtype=np.int64)
     except OverflowError:
-        msg = ("Individual bounds must be able to be represented as a "
-               "signed 64-bit number, and hence must lie in the range "
-               "(-9223372036854775808, 9223372036854775807).")
+        msg = (
+            "Individual bounds must be able to be represented as a "
+            "signed 64-bit number, and hence must lie in the range "
+            "(-9223372036854775808, 9223372036854775807)."
+        )
         raise ValueError(msg)
     if np.isclose(lower_bound, upper_bound):
         return lower_bound
     if lower_bound > upper_bound:
-        msg = (f"Lower bound ({lower_bound}) at index 0 must be less "
-               f"than upper bound ({upper_bound}) at index 1.")
+        msg = (
+            f"Lower bound ({lower_bound}) at index 0 must be less "
+            f"than upper bound ({upper_bound}) at index 1."
+        )
         raise ValueError(msg)
     return tuple(bounds)
