@@ -6,25 +6,25 @@ well-formatted console output, usually to be used in error messages.
 
 """
 
-from .format_str_case import (format_str_case, START_STR_CASE_FORMAT_KEYWORD)
+
+from .format_str_case import START_STR_CASE_FORMAT_KEYWORD, format_str_case
 
 
-def generate_name_description_error_message(name,
-                                            description,
-                                            is_sentence_start=False,
-                                            with_preposition=False):
+def generate_name_description_error_message(
+    name, description, is_sentence_start=False, with_preposition=False
+):
     """Combine the name and description for correctly-formatted error.
 
     Parameters
     ----------
-    is_sentence_start : bool, optional
+    is_sentence_start : Optional[bool]
         Should the formatted str be return in start case.
-    with_preposition : bool, optional
+    with_preposition : Optional[bool]
         Should 'a' or 'an' be preappended to the error message.
 
     Returns
     -------
-    :py:obj:`str`
+    str
         Formatted description.
 
     """
@@ -42,30 +42,36 @@ def generate_name_description_error_message(name,
     else:
         formatted_description = description
     if is_sentence_start:
-        formatted_description = format_str_case(formatted_description,
-                                                START_STR_CASE_FORMAT_KEYWORD,
-                                                process=True)
+        formatted_description = format_str_case(
+            formatted_description, START_STR_CASE_FORMAT_KEYWORD, process=True
+        )
     return f"{formatted_description} (`{name}`)"
 
 
-def format_multiple_items_for_output(items, wrapping_char="`", *,
-                                     prefix_char="", case=None,
-                                     with_verb=False, with_or=False):
+def format_multiple_items_for_output(
+    items,
+    wrapping_char="`",
+    *,
+    prefix_char="",
+    case=None,
+    with_verb=False,
+    with_or=False,
+):
     """Format multiple items for pretty console output.
 
     Parameters
     ----------
-    items : iterable of str
+    items : Iterable[str]
         Items to be formatted.
-    wrapping_char : str (default `"'"`)
+    wrapping_char : str
         Prefix and suffix character for format wrapping.
-    prefix_char : str (default `""`)
+    prefix_char : str
         Additional prefix.
-    case : str (default `None`)
-        Keyword for :func:`format_str_case`.
-    with_verb : bool, optional (default `False`)
+    case : Optional[str]
+        Keyword for :func:`pyproprop.format_str_case`.
+    with_verb : Optional[bool]
         Append the correct conjugation of "is"/"are" to end of list.
-    with_or : bool, optional
+    with_or : Optional[bool]
         Description
 
     Returns
@@ -75,17 +81,21 @@ def format_multiple_items_for_output(items, wrapping_char="`", *,
 
     """
     items = format_as_iterable(items)
-    items = [f"{prefix_char}"
-             f"{repr(format_str_case(item, case)) if isinstance(item, str) else repr(item)}"
-             for item in items]
+    items = [
+        f"{prefix_char}"
+        f"{repr(format_str_case(item, case)) if isinstance(item, str) else repr(item)}"
+        for item in items
+    ]
     if len(items) == 1:
         formatted_items = f"{wrapping_char}{items[0]}{wrapping_char}"
     else:
         pad = f"{wrapping_char}, {wrapping_char}"
         joiner = "or" if with_or else "and"
-        formatted_items = (f"{wrapping_char}{pad.join(items[:-1])}"
-                           f"{wrapping_char} {joiner} {wrapping_char}"
-                           f"{items[-1]}{wrapping_char}")
+        formatted_items = (
+            f"{wrapping_char}{pad.join(items[:-1])}"
+            f"{wrapping_char} {joiner} {wrapping_char}"
+            f"{items[-1]}{wrapping_char}"
+        )
     verb = "is" if len(items) == 1 else "are"
     if with_verb:
         formatted_items = f"{formatted_items} {verb}"
@@ -101,7 +111,7 @@ def format_for_output(items, *args, **kwargs):
 
     Parameters
     ----------
-    items : iterable
+    items : Iterable
         Items to be formatted for output.
     *args
         Variable length argument list.
@@ -133,9 +143,9 @@ def format_as_iterable(items):
 
     """
     if isinstance(items, str):
-        return (items, )
+        return (items,)
     try:
         iter(items)
     except TypeError:
-        return (items, )
+        return (items,)
     return items
